
<h1 align="center">
  <br>
  primaryschool
  <br>
</h1>

<h4 align="center">
    primary school knowledge games.
</h4>

<p align="center">
    <a href="https://badge.fury.io/py/primaryschool">
        <img src="https://badge.fury.io/py/primaryschool.svg" 
            alt="PyPI version" height="18" />
    </a>
</p>

<p align="center">
  <a href="#how-to-use">How To Use</a> 
  • 
  <a href="#todo-list">Todo List</a> 
  • 
  <a href="#credits">Credits</a> 
  • 
  <a href="#license">License</a>
</p>

![screenshot](https://github.com/larryw3i/primaryschool/blob/daily/primaryschool/resource/imgs/0x1.png?raw=true)

## How To Use

To run this application, you'll need 
[Python3](https://www.python.org/downloads/) and 
[python3-pip](https://pypi.org/) 
(which comes with [Python3](https://www.python.org/downloads/) generally, 
Unix-like may need to install separately.) 
installed on your computer. From your command line:
```bash
pip3 install -U primaryschool; primaryschool
```  

## Todo List
- [ ] Games Search

## Credits

This software uses the following open source packages:

- [pygame](https://github.com/pygame/pygame)
- [pygame-menu](https://github.com/ppizarror/pygame-menu)
- [xpinyin](https://github.com/lxneng/xpinyin)
- [appdirs](https://github.com/ActiveState/appdirs)


## License

[MIT License](LICENSE)

---

